@@ -21,7 +21,10 @@
 #ifndef __EXIF_CANON_TAG_H__
 #define __EXIF_CANON_TAG_H__
 
-typedef enum _ExifCanonTag ExifCanonTag;
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 enum _ExifCanonTag {
 	EXIF_CANON_TAG_UNKNOWN_0	= 0x0,
 	EXIF_CANON_TAG_SETTINGS_1	= 0x1,
@@ -36,7 +39,12 @@ enum _ExifCanonTag {
 	EXIF_CANON_TAG_UNKNOWN_13	= 0xd,
 	EXIF_CANON_TAG_CUSTOM_FUNCS	= 0xf
 };
+typedef enum _ExifCanonTag ExifCanonTag;
 
 const char *exif_canon_tag_get_name (ExifCanonTag tag);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #endif /* __EXIF_CANON_TAG_H__ */
