@@ -21,7 +21,10 @@
 #ifndef __EXIF_OLYMPUS_TAG_H__
 #define __EXIF_OLYMPUS_TAG_H__
 
-typedef enum _ExifOlympusTag ExifOlympusTag;
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 enum _ExifOlympusTag {
 	EXIF_OLYMPUS_TAG_MODE		= 0x0200,
 	EXIF_OLYMPUS_TAG_QUALITY	= 0x0201,
@@ -35,7 +38,12 @@ enum _ExifOlympusTag {
 	EXIF_OLYMPUS_TAG_ID		= 0x0209,
 	EXIF_OLYMPUS_TAG_UNKNOWN_4	= 0x0f04
 };
+typedef enum _ExifOlympusTag ExifOlympusTag;
 
 const char *exif_olympus_tag_get_name (ExifOlympusTag tag);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #endif /* __EXIF_OLYMPUS_TAG_H__ */
